@@ -7,8 +7,10 @@
 #ifndef WORKER_H
 #define WORKER_H
 
-#include <QObject>
 #include <KFileMetaData/Properties>
+#include <QImage>
+#include <QObject>
+#include <kconfig_version.h>
 #include <memory>
 
 class KConfig;
@@ -17,16 +19,21 @@ class Worker : public QObject
 {
     Q_OBJECT
 public:
-    static Worker* instance();
+    static Worker *instance();
 
 Q_SIGNALS:
+#if KCONFIG_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+    void metaDataReady(int index, KFileMetaData::PropertyMultiMap metadata);
+#else
     void metaDataReady(int index, KFileMetaData::PropertyMap metadata);
-    void thumbnailSuccess(const QImage &image);
+#endif
+    void thumbnailSuccess(const QString &id, const QImage &image);
     void thumbnailFail();
 
 public Q_SLOTS:
     void getMetaData(int index, const QString &path);
     void makePlaylistThumbnail(const QString &id, int width);
+    QImage frameToImage(const QString &id, int width);
     void syncConfigValue(QString path, QString group, QString key, QVariant value);
 
 private:
